summaryrefslogtreecommitdiff
path: root/zephyr/zmake
diff options
context:
space:
mode:
authorYuval Peress <peress@chromium.org>2021-06-17 11:43:32 -0600
committerCommit Bot <commit-bot@chromium.org>2021-06-17 23:26:24 +0000
commitb2040ed78b24b1175744e7f8201ab1fe591e852a (patch)
tree65ed11809fbcd67a1acb3b8236aea2a302c89dd9 /zephyr/zmake
parent50b839d7e64fcb3066245e9b05eee6fbc88c0bd5 (diff)
downloadchrome-ec-b2040ed78b24b1175744e7f8201ab1fe591e852a.tar.gz
zmake: update NPCX_IMAGE_FILE name to match zephyr 2.6
In Zephyr v2.6 we no longer have the option of setting the output file name. Set it to match so projects can build with either 2.5 or 2.6 BRANCH=none BUG=b:190731415 TEST=build projects with 2.5 and 2.6 Signed-off-by: Yuval Peress <peress@chromium.org> Change-Id: I3637e832eeac43e497f31dd1bf60bcd525b4497c Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2970985 Reviewed-by: Denis Brockus <dbrockus@chromium.org>
Diffstat (limited to 'zephyr/zmake')
-rw-r--r--zephyr/zmake/zmake/output_packers.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/zephyr/zmake/zmake/output_packers.py b/zephyr/zmake/zmake/output_packers.py
index 1e09e9d580..478eb4c24d 100644
--- a/zephyr/zmake/zmake/output_packers.py
+++ b/zephyr/zmake/zmake/output_packers.py
@@ -104,7 +104,7 @@ class NpcxPacker(BasePacker):
"""Packer for RO/RW image to generate a .bin build using FMAP.
This expects that the build is setup to generate a
zephyr.packed.bin for the RO image, which should be packed using
Nuvoton's loader format.
"""
def __init__(self, project):
@@ -137,7 +137,7 @@ class NpcxPacker(BasePacker):
# Copy the inputs into the work directory so that Binman can
# find them under a hard-coded name.
- shutil.copy2(ro / 'zephyr' / 'zephyr.packed.bin',
+ shutil.copy2(ro / 'zephyr' / 'zephyr.npcx.bin',
work_dir / 'zephyr_ro.bin')
shutil.copy2(rw / 'zephyr' / 'zephyr.bin', work_dir / 'zephyr_rw.bin')
@@ -104,7 +104,7 @@ class NpcxPacker(BasePacker):
"""Packer for RO/RW image to generate a .bin build using FMAP.
This expects that the build is setup to generate a
- zephyr.packed.bin for the RO image, which should be packed using
+ zephyr.npcx.bin for the RO image, which should be packed using
Nuvoton's loader format.
"""